@@ -125,7 +125,7 @@ void read_conf (void)
 	file = fopen (wvconf, "r");
 	
 	if (file == NULL) {
-		creat (wvconf, S_IRUSR|S_IWUSR);
+		chmod (wvconf, S_IRUSR|S_IWUSR);
 		file = fopen (wvconf, "w");
 		g_fprintf (file, "Init2 = ATQ0 V1 E1 S0=0 &C1 &D2 +FCLASS=0\n");
 		fclose (file);
@@ -694,7 +694,7 @@ void write_conf()
 	home = g_get_home_dir ();
 	wvconf = g_build_filename (home, ".wvdial.conf", NULL);
 
-	creat (wvconf, S_IRUSR|S_IWUSR);	
+	chmod (wvconf, S_IRUSR|S_IWUSR);
 	file = fopen (wvconf, "w");
 	
 	g_fprintf (file, "[Dialer Defaults]\n");
@@ -712,12 +712,14 @@ void write_conf()
 	}
 	g_fprintf (file, "Baud = %s\n", speed);
 	
-	if (volume == 0)
+	if (volume == 0 && type != 2)
 		str_volume = g_strdup ("ATM0L0");
-	else if ( volume == 1)
+	else if ( volume == 1 && type != 2)
 		str_volume = g_strdup ("ATM1L1");
-	else if (volume == 2)
+	else if (volume == 2 && type != 2)
 		str_volume = g_strdup ("ATM1L3");
+	else
+		str_volume = g_strdup ("AT");
 	
 	if (dial_tone == TRUE)
 		g_fprintf (file, "Init = ATZ\n");
@@ -740,14 +742,17 @@ void write_conf()
 	g_fprintf (file, "Dial Prefix = %s\n", prefix);
 	g_fprintf (file, "Dial Attempts = %d\n", (gint)attempts);
 	
-	if (tone == TRUE && pulse == FALSE) {
+	if (tone == TRUE && pulse == FALSE && type != 2) {
 		g_fprintf (file, "Dial Command = %s", str_volume);
 		g_fprintf (file, "DT\n");
-	} else if ( tone == FALSE && pulse == TRUE ) {
+	} else if (tone == FALSE && pulse == TRUE && type != 2) {
 		g_fprintf (file, "Dial Command = %s", str_volume);
 		g_fprintf (file, "DP\n");
 	}
-	
+	else {
+		g_fprintf (file, "Dial Command = %s", str_volume);
+		g_fprintf (file, "\n");
+	}
 	g_free (str_volume);
 	
 	if (dynamic_ip == FALSE && static_ip == TRUE)
